summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
m---------cmake0
-rw-r--r--src/gui/kdeext/klearlook.cpp6
2 files changed, 3 insertions, 3 deletions
diff --git a/cmake b/cmake
-Subproject 9a217903f9fa35ca12213a6e9ee3d2cb87d1131
+Subproject 274366fb8b90704586d7beef216b765cc0688b0
diff --git a/src/gui/kdeext/klearlook.cpp b/src/gui/kdeext/klearlook.cpp
index cf4eb39..ca7f26a 100644
--- a/src/gui/kdeext/klearlook.cpp
+++ b/src/gui/kdeext/klearlook.cpp
@@ -168,7 +168,7 @@ inline TQColor midColor( const TQColor &a, const TQColor &b, double factor = 1.0
// Copied from Keramik...
static bool isFormWidget( const TQWidget *widget ) {
//Form widgets are in the KHTMLView, but that has 2 further inner levels
//of widgets - TQClipperWidget, and outside of that, TQViewportWidget
TQWidget * potentialClipPort = widget->parentWidget();
@@ -180,9 +180,9 @@ static bool isFormWidget( const TQWidget *widget ) {
if ( !potentialViewPort || potentialViewPort->isTopLevel() || qstrcmp( potentialViewPort->name(), "qt_viewport" ) )
return false;
- TQWidget *potentialKHTML = potentialViewPort->parentWidget();
+ TQWidget *potentialTDEHTML = potentialViewPort->parentWidget();
- if ( !potentialKHTML || potentialKHTML->isTopLevel() || qstrcmp( potentialKHTML->className(), "KHTMLView" ) )
+ if ( !potentialTDEHTML || potentialTDEHTML->isTopLevel() || qstrcmp( potentialTDEHTML->className(), "TDEHTMLView" ) )
return false;
return true;
@@ -168,7 +168,7 @@ inline TQColor midColor( const TQColor &a, const TQColor &b, double factor = 1.0
// Copied from Keramik...
static bool isFormWidget( const TQWidget *widget ) {
- //Form widgets are in the KHTMLView, but that has 2 further inner levels
+ //Form widgets are in the TDEHTMLView, but that has 2 further inner levels
//of widgets - TQClipperWidget, and outside of that, TQViewportWidget
TQWidget * potentialClipPort = widget->parentWidget();